@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Vimana::Index;
 
-use vars qw($INDEX $CACHE);
+use vars qw($INDEX);
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Vimana - Vim script manager.
 
 =cut
 
-our $VERSION = 2009.34614 ;
+our $VERSION = 2009.34902 ;
 
 =head1 DESCRIPTION
 
@@ -43,20 +43,6 @@ NOTE: Vimana only provides search,info,install commmands currently.
 
 =head1 FUNCTIONS
 
-=head2 cache
-
-=cut
-
-sub cache {
-    return $CACHE if $CACHE;
-    my $cache = Cache::File->new(
-        cache_root      => $ENV{VIMANA_CACHE_DIR} || '/tmp/vim.get',
-        lock_level      => Cache::File::LOCK_LOCAL(),
-        default_expires => '3 hours'
-    );
-    return $CACHE = $cache;
-}
-
 =head2 index
 
 =cut
